@@ -9,7 +9,7 @@ require DynaLoader;
 use vars qw($VERSION @ISA $__import @preload $pid);
 @ISA = qw(DynaLoader);
 sub dl_load_flags { 0x00 }
-$VERSION = '1.71';
+$VERSION = '1.72';
 $pid = $$;
 bootstrap Prima $VERSION;
 unless ( UNIVERSAL::can('Prima', 'init')) {
@@ -452,6 +452,8 @@ L<Prima::Drawable::Metafile> - graphics recorder
 
 L<Prima::Drawable::Path> - stroke and fill complex paths
 
+L<Prima::Drawable::Pod> - POD parser and renderer
+
 L<Prima::Drawable::Subcanvas> - paint a hierarchy of widgets to any drawable
 
 L<Prima::Drawable::TextBlock> - rich text representation
@@ -466,6 +468,8 @@ L<prima-cfgmaint> - configuration tool for Visual Builder
 
 L<Prima::VB::CfgMaint> - configures the widget palette in the Visual Builder
 
+L<prima-fmview> - .fm file viewer
+
 =item PostScript printer interface
 
 L<Prima::PS::PostScript> - PostScript interface to C<Prima::Drawable>
@@ -510,6 +514,8 @@ L<Prima::codecs>    - Step-by-step image codec creation
 
 L<prima-gencls>     - C<prima-gencls>, a class compiler tool.
 
+L<prima-tmlink>     - C<prima-tmlink>, optimizer tool for files produced by prima-gencls.
+
 =item Miscellaneous
 
 L<Prima::faq> - frequently asked questions
@@ -522,8 +528,14 @@ L<Prima::Image::Animate> - animate gif and webp files
 
 L<Prima::Image::base64> - hardcoded image files
 
+L<Prima::Image::Loader> - progressive loading and saving for multiframe images
+
 L<Prima::IniFile> - support of Windows-like initialization files
 
+L<podview> - POD viewer
+
+L<pod2pdf> - POD printer
+
 L<Prima::StdBitmap> - shared access to the standard bitmaps
 
 L<Prima::Stress> - stress test module
