@@ -92,8 +92,8 @@ sub list
 }
 
 sub TIEARRAY  { bless \@_, shift }
-sub FETCH     { unpack( $_[0]->[PACK], CORE::substr( $_[0]->[REF], $_[1] * $_[0]->[SIZE], $_[0]->[SIZE] )) }
-sub STORE     { CORE::substr( $_[0]->[REF], $_[1] * $_[0]->[SIZE], $_[0]->[SIZE], pack( $_[0]->[PACK], $_[2] )) }
+# sub FETCH   { unpack( $_[0]->[PACK], CORE::substr( $_[0]->[REF], $_[1] * $_[0]->[SIZE], $_[0]->[SIZE] )) } # optimized in C
+# sub STORE     { CORE::substr( $_[0]->[REF], $_[1] * $_[0]->[SIZE], $_[0]->[SIZE], pack( $_[0]->[PACK], $_[2] )) }
 sub FETCHSIZE { length( $_[0]->[REF] ) / $_[0]->[SIZE] }
 sub EXISTS    { $_[1] < FETCHSIZE($_[0]) }
 sub EXTEND    { $_[0]->[REF] .= "\x0" x ($_[1] * $_[0]->[SIZE] - length $_[0]->[REF]) }
@@ -401,6 +401,7 @@ GENPROC
 
 for ( qw( ascent descent family weight maximalWidth internalLeading externalLeading
 	xDeviceRes yDeviceRes firstChar lastChar breakChar defaultChar 
+	underlinePosition underlineThickness
 )) {
 	eval <<GENPROC;
    sub $_
@@ -770,7 +771,7 @@ sub put_image
 	$_[0]-> put_image_indirect(
 		@_[3,1,2], 0, 0,
 		($_[3]-> size) x 2,
-		defined ($_[4]) ? $_[4] : $_[0]-> rop
+		$_[4] // rop::Default
 	) if $_[3]
 }
 
@@ -778,7 +779,7 @@ sub stretch_image {
 	$_[0]-> put_image_indirect(
 		@_[5,1,2], 0, 0,
 		@_[3,4], $_[5]-> size,
-		defined ($_[6]) ? $_[6] : $_[0]-> rop
+		$_[6] // rop::Default
 	) if $_[5]
 }
 
@@ -983,6 +984,16 @@ sub save_stream
 	return $ok;
 }
 
+sub has_codec
+{
+	my $what = $_[1];
+	my @ret;
+	for ( @{ Prima::Image->codecs }) {
+		push @ret, $_ if $_->{fileShortType} =~ m/$what/;
+	}
+	return wantarray ? @ret : $ret[0];
+}
+
 package Prima::Icon;
 use vars qw( @ISA);
 @ISA = qw(Prima::Image);
@@ -1076,7 +1087,7 @@ sub image
 	my ($image, undef) = $self-> split;
 	$image->backColor($opt{background} // 0);
 	$image->clear;
-	$image->put_image(0,0,$self,rop::CopyPut);
+	$image->put_image(0,0,$self,rop::Default);
 	return $image;
 }
 
@@ -1129,9 +1140,7 @@ sub dup
 		size => [ $self->size ],
 		type => $self->type
 	);
-	$dup->backColor(0);
-	$dup->clear;
-	$dup->put_image(0,0,$self,rop::Blend);
+	$dup->put_image(0,0,$self,rop::CopyPut);
 	return $dup;
 }
 
@@ -1866,8 +1875,8 @@ sub begin_drag
 			$i->maskType(8);
 			$p->maskType(8)
 				if $p->isa('Prima::Icon');
-			$n->put_image( 0, $p->height, $i, rop::SrcCopy);
-			$n->put_image( $i->width, 0, $p, rop::SrcCopy);
+			$n->put_image( 0, $p->height, $i, rop::CopyPut);
+			$n->put_image( $i->width, 0, $p, rop::CopyPut);
 			$n->bar_alpha(0xff, $i->width, 0, $i->width + $p->width - 1, $p->height - 1)
 				if !$p->isa('Prima::Icon');
 			$n->{__pointerHotSpot} = \@hs;
