@@ -4,30 +4,35 @@ use strict;
 use warnings;
 use Carp;
 use Prima;
+use Prima::Image::Loader;
 
 sub new
 {
 	my $class = shift;
 	my $self = bless {
-		images     => [],
+		loadAll    => 0,
 		model      => 'gif',
 		@_,
 		current    => -1,
 	}, $class;
 
-	$self-> reset;
+	$self->{loadAll} = 1 if $self->{images};
+	$self->{images} //= [] if $self->{loadAll};
 
+	$self-> reset;
 	return $self;
 }
 
 sub detect_animation
 {
-	my (undef, $extras) = @_;
+	my (undef, $extras, $min_frames) = @_;
+
+	$min_frames //= 2;
 	return undef unless                    # more than 1 frame?
 		$extras &&
 		defined($extras->{codecID}) &&
 		$extras->{frames} &&
-		$extras->{frames} > 1;
+		$extras->{frames} >= $min_frames;
 	my $c = Prima::Image->codecs($extras-> {codecID}) or return 0;
 	return undef unless $c;
 
@@ -53,29 +58,49 @@ sub load
 		$hash-> {$k} = $v;
 	}
 
-	my $i = Prima::Icon-> new(%events); # dummy object
+	if ( $opt{loadAll}) {
+		my $i = Prima::Icon-> new(%events); # dummy object
 
-	my @i = grep { defined } $i-> load(
-		$where,
-		loadExtras => 1,
-		loadAll    => 1,
-		iconUnmask => 1,
-		blending   => 1,
-		%args,
-	);
-	warn $@ if @i && !$i[-1];
+		my @i = grep { defined } $i-> load(
+			$where,
+			loadExtras => 1,
+			loadAll    => 1,
+			iconUnmask => 1,
+			blending   => 1,
+			%args,
+		);
 
-	return unless @i;
+		return (undef, $@) unless @i && $i[-1];
 
-	my $model = $class->detect_animation($i[0]->{extras}) or return;
-	$model = 'Prima::Image::Animate::' . $model;
+		my $model = $class->detect_animation($i[0]->{extras}, 1);
+		return (undef, "not a recognized image or animation") unless $model;
 
-	return $model-> new( images => \@i);
+		$model = 'Prima::Image::Animate::' . $model;
+		return $model-> new( images => \@i);
+	} else {
+		my ($l,$error) = Prima::Image::Loader->new(
+			$where,
+			icons      => 1,
+			iconUnmask => 1,
+			blending   => 1,
+			%args,
+		);
+		return (undef, $error) unless $l;
+
+		my $model = $class->detect_animation($l->{extras}, 1);
+		return (undef, "not a recognized image or animation") unless $model;
+
+		$model = 'Prima::Image::Animate::' . $model;
+		return $model-> new( loader => $l );
+	}
 }
 
+sub loader { shift->{loader} }
+
 sub add
 {
 	my ( $self, $image) = @_;
+	croak "cannot add an image to a progressive animation loader" unless $self->{loadAll};
 	push @{$self-> {images}}, $image;
 }
 
@@ -112,6 +137,16 @@ sub union_rect
 	return \%ret;
 }
 
+sub total
+{
+	my ( $self, $index ) = @_;
+	return $self->{loadAll} ?
+		scalar @{$self->{images}} :
+		$self->{loader}->frames;
+}
+
+sub get_extras { shift->{image}->{extras} // {} }
+
 sub reset
 {
 	my $self = shift;
@@ -123,37 +158,73 @@ sub reset
 		loopCount changedRect 
 		)};
 
-	my $i = $self-> {images};
-	return unless @$i;
-
-	my $ix = $i-> [0];
+	my $ix;
+	if ( $self->{loadAll}) {
+		my $i = $self-> {images};
+		return unless @$i;
+		$ix = $i-> [0];
+	} else {
+		$self->{loader}->current(0);
+		$ix = $self->load_next_image;
+	}
 	return unless $ix;
 
-	my $e = $self-> get_extras(0);
-	return unless $e;
-
-	$self-> {image} = $self-> {images}-> [0];
-	$self-> {info}  = $e;
+	$self-> {image} = $ix;
+	my $e = $self-> {info}  = $self->get_extras;
 	$self-> {$_} = $e-> {$_} for qw(screenWidth screenHeight);
 	$self-> {changedRect} = {};
 	$self-> fixup_rect( $e, $ix);
+}
 
+sub warning { shift->{warning} }
+
+sub load_next_image
+{
+	my $self = shift;
+	return unless $self->{loader};
+	$self->{warning} = undef;
+	my ( $i, $err ) = $self->{loader}->next;
+	unless ($i) {
+		$self->{warning} = $err;
+		$self->{loader}->reload;
+		( $i, $err ) = $self->{loader}->next;
+		$self->{current} = 0;
+		$self->{warning} = $err unless $i;
+	}
+	return $i;
 }
 
 sub advance_frame
 {
 	my $self = shift;
 
-	delete @{$self}{qw(image info)};
-	if ( ++$self-> {current} >= @{$self-> {images}}) {
+	my ( $oimg, $oinfo) = delete @{$self}{qw(image info)};
+	my $curr = $self->{current};
+	if ( ++$self-> {current} >= $self-> total) {
 		# go back to first frame, or stop
 		if ( defined $self-> {loopCount}) {
 		    return 0 if --$self-> {loopCount} <= 0;
 		}
 		$self-> {current} = 0;
+		$curr = -2;
 	}
-	$self-> {image} = $self-> {images}-> [$self-> {current}];
-	my $info = $self-> {info} = $self-> get_extras( $self-> {current} );
+
+	if ( $self->{loadAll}) {
+		$self->{image} = $self-> {images}-> [$self-> {current}];
+	} elsif ( $curr >= 0 ) {
+		$self->{image} = $self-> load_next_image;
+	} elsif ( $curr == -2 ) {
+		$self-> {loader}->current(0);
+		$self->{image} = $self-> load_next_image;
+	} else {
+		$self->{image} = $oimg;
+	}
+	unless ($self->{image}) {
+		$self->{image} = $oimg;
+		$self->{info} = $oinfo;
+	}
+ 
+	my $info = $self->{info} = $self-> get_extras;
 	$self-> fixup_rect( $info, $self-> {image});
 
 	# load global extension data
@@ -174,7 +245,6 @@ sub next  { die }
 sub icon  { die }
 sub image { die }
 sub draw  { die }
-sub get_extras { die }
 
 sub draw_background
 {
@@ -193,7 +263,7 @@ sub draw_background
 sub is_stopped
 {
 	my $self = shift;
-	return $self-> {current} >= @{$self-> {images}};
+	return $self-> {current} >= $self-> total;
 }
 
 sub width   { $_[0]-> {canvas} ? $_[0]-> {canvas}-> width  : 0 }
@@ -202,15 +272,35 @@ sub size    { $_[0]-> {canvas} ? $_[0]-> {canvas}-> size   : (0,0) }
 sub bgColor { $_[0]-> {bgColor} }
 sub bgAlpha { $_[0]-> {bgAlpha} }
 sub current { $_[0]-> {current} }
-sub total   { scalar @{$_[0]-> {images}} }
 
 sub length
 {
+	my $self = shift;
 	my $length = 0;
-	$length += $_-> {delayTime} || 0 for
-		map { $_-> {extras} || {} }
-		@{$_[0]-> {images}};
-	return $length / 1000;
+	if ( $self->{loadAll}) {
+		$length += $_-> {delayTime} || 0 for
+			map { $_-> {extras} || {} }
+			@{$_[0]-> {images}};
+	} else {
+		return $self->{cached_length} if exists $self->{cached_length};
+
+		my ($l2) = Prima::Image::Loader->new(
+			$self->{loader}->source,
+			noImageData => 1,
+			loadExtras  => 1,
+		);
+		$self->{cached_length} = undef;
+		return undef unless $l2;
+
+		while ( !$l2->eof ) {
+			my ($i) = $l2->next;
+			last unless $i;
+			$length += $i->{extras}->{delayTime} // 0;
+		}
+		$self->{cached_length} = $length / 1000 if defined $length;
+	}
+
+	return defined($length) ? $length / 1000 : undef;
 }
 
 sub loopCount
@@ -229,16 +319,11 @@ use constant DISPOSE_RESTORE_PREVIOUS => 3; # Restore the previous (composited)
 
 sub get_extras
 {
-	my ( $self, $ix) = @_;
-	$ix = $self-> {images}-> [$ix];
-	return unless $ix;
-
-	my $e = $ix-> {extras} || {};
-
-	$e-> {screenHeight}     ||= $ix-> height;
-	$e-> {screenWidth}      ||= $ix-> width;
+	my $self = shift;
+	my $e  = $self->SUPER::get_extras;
+	$e-> {screenHeight} ||= $self->{image}-> height;
+	$e-> {screenWidth}  ||= $self->{image}-> width;
 	$e-> {$_} ||= 0 for qw(disposalMethod useScreenPalette delayTime left top);
-
 	return $e;
 }
 
@@ -326,7 +411,7 @@ sub reset
 	my $self = shift;
 	$self-> SUPER::reset;
 
-	my $e = $self-> get_extras(0);
+	my $e = $self-> {info};
 	return unless $e;
 
 	$self-> {$_} = $e-> {$_} for qw(screenWidth screenHeight);
@@ -353,7 +438,7 @@ sub reset
 		my $cm =
 			$e-> {useScreenPalette} ?
 				$e-> {screenPalette} :
-				$self-> {images}-> [0]-> palette;
+				$self-> {image}-> palette;
 		my $i = $e-> {screenBackGroundColor} * 3;
 		$self-> {bgColor} = cl::from_rgb(map { $_ || 0 } @$cm[$i..$i+2]);
 		$self-> {bgAlpha} = 0xff;
@@ -410,25 +495,27 @@ sub new
 	return $class->SUPER::new(%opt);
 }
 
+sub load_next_image
+{
+	my $i = shift->SUPER::load_next_image;
+	$i->maskType(im::bpp8) if $i && $i->isa('Prima::Icon');
+	return $i;
+}
+
 sub get_extras
 {
-	my ( $self, $ix) = @_;
-	$ix = $self-> {images}-> [$ix];
-	return unless $ix;
-
-	my $e = $ix-> {extras} || {};
-
-	$e-> {screenHeight}     ||= $ix-> height;
-	$e-> {screenWidth}      ||= $ix-> width;
+	my $self = shift;
+	my $e  = $self->SUPER::get_extras;
+	$e-> {screenHeight} ||= $self->{image}-> height;
+	$e-> {screenWidth}  ||= $self->{image}-> width;
 	$e-> {$_} ||= 0 for qw(disposalMethod blendMethod delayTime left top);
-
 	return $e;
 }
 
 sub next
 {
 	my $self = shift;
-	my $info = $self->{info};
+	my $info = $self->{info} or return;
 	my %ret;
 
 	if ( $info-> {disposalMethod} eq 'restore') {
@@ -462,7 +549,7 @@ sub next
 		$info-> {rect}-> {left},
 		$info-> {rect}-> {bottom},
 		$self-> {image},
-		(( $info-> {blendMethod} eq 'blend') ? rop::Blend : rop::SrcCopy)
+		(( $info-> {blendMethod} eq 'blend') ? rop::SrcOver : rop::SrcCopy)
 	);
 
 	$ret{$_} ||= 0 for qw(left bottom right top);
@@ -476,7 +563,7 @@ sub reset
 	my $self = shift;
 	$self-> SUPER::reset;
 
-	my $e = $self-> get_extras(0);
+	my $e = $self-> {info};
 	return unless $e;
 
 	$self-> {canvas}  = Prima::Icon-> new(
@@ -494,7 +581,7 @@ sub reset
 	}
 }
 
-sub icon  { shift->{canvas}->icon }
+sub icon  { shift->{canvas}->dup }
 sub image { shift->{canvas}->image }
 
 sub draw
@@ -518,6 +605,28 @@ sub new
 	return $self;
 }
 
+sub load_next_image
+{
+	my ( $self ) = shift;
+	my $i = $self->SUPER::load_next_image;
+	return unless $i;
+
+	if ( $self->{loader}->current == 1 && $i->{extras}->{default_frame} ) {
+		$self->{skip_default_frame} = 1;
+		return $self->SUPER::load_next_image;
+	}
+
+	return $i;
+}
+
+sub total
+{
+	my $self = shift;
+	my $total = $self->SUPER::total;
+	$total-- if $self->{skip_default_frame};
+	return $total;
+}
+
 1;
 
 __END__
@@ -574,10 +683,16 @@ format name on success, undef otherwise.
 Loads a GIF, APNG, or WebP animation sequence from C<$SOURCE> which is either a
 file or a stream. Options are the same as used by the C<Prima::Image::load> method.
 
+Depending on the C<loadAll> option, either loads all frames at once (1), or uses
+C<Prima::Image::Loader> to load only a single frame at a time (0, default).
+Depending on the loading mode, some properties may not be available.
+
 =head2 add $IMAGE
 
 Appends an image frame to the container.
 
+Only available if the C<loadAll> option is on.
+
 =head2 bgColor
 
 Returns the background color specified by the sequence as the preferred
@@ -657,13 +772,20 @@ Returns the width and height of the composite frame
 
 Return the number of frames
 
+=head2 warning
+
+If an error occured during frame loading, it will be stored in the C<warning>
+property. The animation will stop at the last successfully loaded frame
+
+Only available if the C<loadAll> option is off.
+
 =head2 width
 
 Returns the width of the composite frame
 
 =head1 SEE ALSO
 
-L<Prima::image-load>
+L<Prima::image-load>, L<Prima::Image::Loader>.
 
 =head1 AUTHOR
 
