@@ -78,6 +78,7 @@ sub change_transform
 		$ps->[0] - $pm->[2] - $pm->[0],
 		$ps->[1] - $pm->[3] - $pm->[1]
 	);
+	@pm[0,1] = (0,0) if $self->{lock_margins};
 
 	my ($doClip, @cr);
 	my $rg = $self-> region;
@@ -353,7 +354,7 @@ sub emit_new_dummy_object
 sub begin_doc
 {
 	my ( $self, $docName) = @_;
-	return 0 if $self-> get_paint_state;
+	$@ = 'Bad object', return 0 if $self-> get_paint_state;
 
 	$self-> {ps_data}  = '';
 	$self-> {can_draw} = 1;
@@ -405,13 +406,13 @@ ROOT
 	$self-> {all_alphas}    = {};
 	unless ($self-> {page_content} = $self->new_file_obj) {
 		$self-> abort_doc;
-		return 0;
+		$@ = 'Cannot create temp file', return 0;
 	}
 
 	$self-> {changed} = { map { $_ => 0 } qw(
 		fill lineEnd linePattern lineWidth lineJoin miterLimit font)};
 
-	$self-> SUPER::begin_paint;
+	$self-> {paint_state} = ps::Enabled;
 	$self-> save_state;
 
 	$self-> {delay} = 1;
@@ -497,7 +498,7 @@ sub abort_doc
 	my $self = $_[0];
 	return unless $self-> {can_draw};
 	$self-> {can_draw} = 0;
-	$self-> SUPER::end_paint;
+	delete $self->{paint_state};
 	$self-> abandon_state;
 	delete $self-> {$_} for
 		qw (save_state ps_data changed );
@@ -509,7 +510,7 @@ sub end_paint   {        $_[0]-> abort_doc; }
 sub end_doc
 {
 	my $self = $_[0];
-	return 0 unless $self-> {can_draw};
+	$@ = 'Bad object', return 0 unless $self-> {can_draw};
 	$self-> end_page;
 
 	my $pages = scalar @{ $self->{pages} };
@@ -657,7 +658,7 @@ TRAILER
 	$self->{ps_data} = '';
 
 	$self-> {can_draw} = 0;
-	$self-> SUPER::end_paint;
+	delete $self->{paint_state};
 	$self-> restore_state;
 	delete $self-> {$_} for
 		qw (save_state changed ps_data glyph_keeper glyph_font);
@@ -849,6 +850,7 @@ sub graphic_context_push
 	my $self = shift;
 	return 0 unless $self->SUPER::graphic_context_push;
 	$self->emit_content('q');
+	$self->{lock_margins}++;
 	return 1;
 }
 
@@ -857,6 +859,7 @@ sub graphic_context_pop
 	my $self = shift;
 	$self->emit_content('Q');
 	return unless $self->SUPER::graphic_context_pop;
+	$self->{lock_margins}--;
 	return 1;
 }
 
@@ -947,12 +950,20 @@ sub text_out_outline
 {
 	my ( $self, $text ) = @_;
 	my $shaped   = $self->text_shape($text, level => ts::Glyphs ) or return;
+	local $self->{allow_multi_tj} = 1;
 	$self-> glyph_out_outline($shaped, 0, scalar @{$shaped->glyphs});
 }
 
+sub text_shape_out
+{
+	my $self = shift;
+	local $self->{allow_multi_tj} = 1;
+	return $self->SUPER::text_shape_out(@_);
+}
+
 sub glyph_out_outline
 {
-	my ( $self, $text, $from, $len ) = @_;
+	my ( $self, $text, $from, $len) = @_;
 
 	my $glyphs     = $text-> glyphs;
 	my $indexes    = $text-> indexes;
@@ -963,7 +974,7 @@ sub glyph_out_outline
 	my @ix_lengths = defined($plaintext) ? $text-> index_lengths : ();
 	my $adv        = 0;
 	my $canvas     = $self->glyph_canvas;
-	my $resolution = 72.27 / $self->{resolution}->[0];
+	my $resolution = 72.0 / $self->{resolution}->[0];
 	my $keeper     = $self->{glyph_keeper};
 	my $font       = $self->{glyph_font};
 	my $div        = $self->{font_scale};
@@ -972,9 +983,10 @@ sub glyph_out_outline
 	$len += $from;
 	my $emit = '';
 	my $fid  = 0;
-	my $ff = $canvas->font;
 	my $curr_subfont = -1;
 	my ($x, $y) = (0,0);
+	my $allow_tj = $self->{allow_multi_tj};
+	my @multi_tj;
 	for ( my $i = $from; $i < $len; $i++) {
 		my $advance;
 		my $glyph     = $glyphs->[$i];
@@ -1004,6 +1016,21 @@ sub glyph_out_outline
 			$curr_subfont = $subfont;
 			my $xid = $self-> {all_fonts}-> {$font}-> {xids}-> [ $subfont ] //= $self->new_dummy_obj;
 			$self->{page_fonts}->{$xid} //= 1;
+			if ( @multi_tj ) {
+				($x2, $y2) = $self->pixel2point($x2, $y2);
+				my $dx = $x2 - $x;
+				my $dy = $y2 - $y;
+				if ($dx != 0 || $dy != 0) {
+					float_inplace($dx, $dy);
+					$emit .= "$dx $dy Td ";
+				}
+				if ( $allow_tj ) {
+					$emit .= "(".join('',@multi_tj).") Tj\n";
+				} else {
+					$emit .= "[".join(' ',@multi_tj)."] TJ\n";
+				}
+				@multi_tj = ();
+			}
 			$emit .= "/F$xid $self->{font}->{size} Tf\n";
 		}
 		if ( $advances) {
@@ -1015,15 +1042,33 @@ sub glyph_out_outline
 			$advance = ($$xr[0] + $$xr[1] + $$xr[2]) * $div;
 		}
 		$adv += $advance;
-		($x2, $y2) = map { int( $_ * 100 + 0.5) / 100 } $self->pixel2point($x2, $y2);
-		my $dx = $x2 - $x;
-		my $dy = $y2 - $y;
-		if  ($dx != 0 || $dy != 0) {
-			float_inplace($dx, $dy);
-			$emit .= "$dx $dy Td ";
+		($x2, $y2) = $self->pixel2point($x2, $y2);
+		if ( defined $gid ) {
+			if ( $allow_tj ) {
+				push @multi_tj, sprintf("\\%03o", $gid);
+			} elsif ( 1 ) {
+				my ($xadv) = float_format($self->pixel2point($advance));
+				push @multi_tj, sprintf("(\\%03o)", $gid), $xadv;
+			} else {
+				# individual placement, obsolete but keep for the reference
+				my $dx = $x2 - $x;
+				my $dy = $y2 - $y;
+				if ($dx != 0 || $dy != 0) {
+					float_inplace($dx, $dy);
+					$emit .= "$dx $dy Td ";
+				}
+				$emit .= sprintf "<%02x> Tj\n", $gid;
+			}
 		}
 		($x, $y) = ($x2, $y2);
-		$emit .= sprintf "<%02x> Tj\n", $gid if defined $gid;
+	}
+	if ( @multi_tj ) {
+		if ( $allow_tj ) {
+			$emit .= "(".join('',@multi_tj).") Tj\n";
+		} else {
+			$emit .= "[".join(' ',@multi_tj)."] TJ\n";
+		}
+		@multi_tj = ();
 	}
 
 	if ($restore_font) {
@@ -1249,6 +1294,8 @@ sub put_image_indirect
 {
 	return 0 unless $_[0]-> {can_draw};
 	my ( $self, $image, $x, $y, $xFrom, $yFrom, $xDestLen, $yDestLen, $xLen, $yLen, $rop) = @_;
+	$rop //= rop::Default;
+	$rop = $image->get_effective_rop($rop);
 	return 1 if $rop == rop::NoOper;
 
 	$image = $self->prepare_image($image, $xFrom, $yFrom, $xLen, $yLen);
@@ -1461,15 +1508,27 @@ Prima::PS::PDF -  PDF interface to Prima::Drawable
 
 =head1 SYNOPSIS
 
-	use Prima;
-	use Prima::PS::PDF;
+Recommended usage:
 
+	use Prima::PS::Printer;
+	my $x = Prima::PS::PDF::File-> new( file => 'out.pdf');
+
+or
+
+	my $x = Prima::PS::PDF::FileHandle-> new( handle => \&STDOUT);
+
+Low-level:
+
+	use Prima::PS::PDF;
 	my $x = Prima::PS::PDF-> create( onSpool => sub {
 		open F, ">> ./test.pdf";
 		binmode F;
 		print F $_[1];
 		close F;
 	});
+
+Printing:
+
 	die "error:$@" unless $x-> begin_doc;
 	$x-> font-> size( 30);
 	$x-> text_out( "hello!", 100, 100);
@@ -1478,7 +1537,7 @@ Prima::PS::PDF -  PDF interface to Prima::Drawable
 
 =head1 DESCRIPTION
 
-Realizes the Prima library interface to PDF v1.4.
+Implements the Prima library interface to PDF v1.4.
 The module is designed to be compliant with the Prima::Drawable interface.
 All properties' behavior is as same as Prima::Drawable's except those
 described below.
