@@ -227,8 +227,8 @@ can_substitute(uint32_t c, int pitch, int fid)
 	if ( !pfe-> ranges_queried )
 		Drawable_query_ranges(pfe);
 
-	if ( 
-		pitch != fpDefault && 
+	if (
+		pitch != fpDefault &&
 		(( pfe->font.undef.pitch || pfe->font.pitch != pitch )) &&
 		!( pfe-> flags & MAPPER_FLAGS_SYNTHETIC_PITCH)
 	)
@@ -390,25 +390,63 @@ prima_font_mapper_action(int action, PFont font)
 	return -1;
 }
 
+void
+Drawable_save_font( Handle self, SaveFont *f)
+{
+	f->font     = var->font;
+	f->restore  = false;
+	f->last_fid = 0;
+}
+
+void
+Drawable_restore_font( Handle self, SaveFont *f)
+{
+	if ( !f->restore )
+		return;
+
+	f-> last_fid = 0;
+	f->restore   = false;
+	if ( Drawable_set_font == my->set_font && (is_opt(optSystemDrawable) || is_opt(optInFontQuery) )) {
+		opt_clear(optFontTrigCache);
+		apc_gp_set_font( self, &f->font);
+	} else
+		my->set_font(self, f->font);
+}
+
 Bool
-Drawable_switch_font( Handle self, uint16_t fid)
+Drawable_switch_font( Handle self, SaveFont *f, uint16_t fid)
 {
 	Font src, dst;
+
+	if ( fid == f-> last_fid )
+		return true;
+
+	if ( fid == 0 ) {
+		Drawable_restore_font( self, f );
+		return true;
+	}
+
 	src = PASSIVE_FONT(fid)->font;
-	if ( is_opt(optSystemDrawable) ) {
+	if ( Drawable_set_font == my->set_font && (is_opt(optSystemDrawable) || is_opt(optInFontQuery) )) {
 		dst = var->font;
-		src.size = dst.size;
-		src.undef.size = 0;
+		src.size         = dst.size;
+		src.height       = dst.height;
+		src.undef.size   = dst.undef.size;
+		src.undef.height = dst.undef.height;
 		apc_font_pick( self, &src, &dst);
 		if ( strcmp(dst.name, src.name) != 0 )
 			return false;
 		apc_gp_set_font( self, &dst);
 	} else {
 		dst = my->get_font(self);
-		src.size = dst.size;
-		src.undef.size = 0;
+		src.size         = dst.size;
+		src.height       = dst.height;
+		src.undef.size   = dst.undef.size;
+		src.undef.height = dst.undef.height;
 		my->set_font(self, src);
 	}
+	f-> restore = true;
+	f-> last_fid = fid;
 	return true;
 }
 
