@@ -44,8 +44,8 @@ sv2uint32( SV * text, unsigned int * size, unsigned int * flags)
 	if (*flags & toUTF8 ) {
 		uint32_t *dst = ret;
 		while ( dlen > 0 && dst - ret < *size) {
-			STRLEN charlen;
 			UV uv;
+			unsigned int charlen;
 			uv = prima_utf8_uvchr(src, dlen, &charlen);
 			if ( uv > 0x10FFFF ) uv = 0x10FFFF;
 			*(dst++) = uv;
@@ -342,13 +342,14 @@ static Bool
 shape_unicode(Handle self, PTextShapeRec t, PTextShapeFunc shaper,
 	Bool glyph_mapper_only, Bool fribidi_arabic_shaping, Bool reorder
 ) {
-	Bool ok, reorder_swaps_rtl, font_changed = false;
+	Bool ok, reorder_swaps_rtl;
 	Byte analysis_buf[MAX_CHARACTERS], *save_analysis, *analysis;
 	uint16_t fonts_buf[MAX_CHARACTERS], *save_fonts, *fonts;
 	uint16_t l2v_buf[MAX_CHARACTERS], *l2v;
 	unsigned int i, run_offs, run_len;
 	semistatic_t p_analysis, p_fonts, p_l2v;
 	BidiRunRec brr;
+	SaveFont savefont;
 
 #ifdef _DEBUG
 	printf("\n%s input: ", (t->flags & toRTL) ? "rtl" : "ltr");
@@ -430,6 +431,7 @@ shape_unicode(Handle self, PTextShapeRec t, PTextShapeFunc shaper,
 	t-> analysis = analysis;
 	save_fonts = t->fonts;
 	if ( t->fonts ) t-> fonts = fonts;
+	Drawable_save_font(self, &savefont);
 	while (( run_len = run_next(t, &brr)) > 0) {
 		TextShapeRec run;
 		run_alloc(t, run_offs, run_len, glyph_mapper_only ^ reorder_swaps_rtl, &run);
@@ -445,20 +447,14 @@ shape_unicode(Handle self, PTextShapeRec t, PTextShapeFunc shaper,
 		printf("\n");
 	}
 #endif
-		if ( t-> fonts && ( run.fonts[0] != 0 || font_changed )) {
-			if ( run.fonts[0] == 0 ) {
-				apc_gp_set_font( self, &var->font);
-			} else {
-				if ( Drawable_switch_font(self, run.fonts[0])) {
+		if ( t-> fonts ) {
+			if ( Drawable_switch_font(self, &savefont, run.fonts[0])) {
 #ifdef _DEBUG
-					printf("%d: set font #%d\n", run_offs, run.fonts[0]);
+				printf("%d: set font #%d\n", run_offs, run.fonts[0]);
 #endif
-					font_changed = true;
-				}
+			} else {
 #ifdef _DEBUG
-				else {
-					printf("%d: failed to set font #%d\n", run_offs, run.fonts[0]);
-				}
+				printf("%d: failed to set font #%d\n", run_offs, run.fonts[0]);
 #endif
 			}
 		}
@@ -498,8 +494,7 @@ shape_unicode(Handle self, PTextShapeRec t, PTextShapeFunc shaper,
 	semistatic_done( &p_fonts);
 	semistatic_done( &p_l2v);
 
-	if ( font_changed )
-		apc_gp_set_font( self, &var->font);
+	Drawable_restore_font( self, &savefont);
 
 	return ok;
 }
@@ -537,7 +532,7 @@ SV*
 Drawable_text_shape( Handle self, SV * text_sv, HV * profile)
 {
 	dPROFILE;
-	gpARGS;
+	dmARGS;
 	int i;
 	SV * ret = NULL_SV, 
 		*sv_glyphs = NULL_SV,
@@ -550,21 +545,21 @@ Drawable_text_shape( Handle self, SV * text_sv, HV * profile)
 	int shaper_type, level = tsDefault, replace_tabs = -1;
 	Bool skip_if_simple = false, return_zero = false, force_advances = false, 
 		reorder = true, polyfont = true, do_replace_tabs = false;
-	Bool gp_enter;
+	Bool dm_enter;
 	semistatic_t p_tabinfo;
 	uint16_t tabinfo_buf[256];
 
 	/* forward, if any */
 	if ( SvROK(text_sv)) {
 		SV * ref = newRV((SV*) profile);
-		gpENTER(NULL_SV);
+		dmENTER(NULL_SV);
 		ret = sv_call_perl(text_sv, "text_shape", "<HS", self, ref);
-		gpLEAVE;
+		dmLEAVE;
 		hv_clear(profile); /* old gencls bork */
 		sv_free(ref);
 		return newSVsv(ret);
 	}
-	CHECK_GP(NULL_SV);
+	dmCHECK(NULL_SV);
 	bzero(&t, sizeof(t));
 
 	/* asserts */
@@ -618,13 +613,13 @@ Drawable_text_shape( Handle self, SV * text_sv, HV * profile)
 	if ( level == tsNone ) {
 		shaper_type    = tsNone;
 		force_advances = false;
-		gp_enter       = false;
+		dm_enter       = false;
 		system_shaper  = bidi_only_shaper;
 	} else {
 		shaper_type    = level;
-		gp_enter       = true;
-		gpENTER(NULL_SV);
-		if (!( system_shaper = apc_gp_get_text_shaper(self, &shaper_type))) {
+		dm_enter       = true;
+		dmENTER(NULL_SV);
+		if (!( system_shaper = apc_font_get_text_shaper(self, &shaper_type))) {
 			return_zero = true;
 			goto EXIT;
 		}
@@ -731,7 +726,7 @@ Drawable_text_shape( Handle self, SV * text_sv, HV * profile)
 		}
 	}
 
-	if (gp_enter) gpLEAVE;
+	if (dm_enter) dmLEAVE;
 
 	/* fix advances for tabs */
 	if ( do_replace_tabs && t.advances) {
@@ -802,7 +797,7 @@ Drawable_text_shape( Handle self, SV * text_sv, HV * profile)
 
 EXIT:
 	if ( replace_tabs >= 0) semistatic_done( &p_tabinfo);
-	if (gp_enter) gpLEAVE;
+	if (dm_enter) dmLEAVE;
 	if ( t.text     ) free(t.text     );
 	if ( t.v2l      ) free(t.v2l      );
 	if ( t.analysis ) free(t.analysis );
