@@ -1746,7 +1746,7 @@ img_put_argb_on_bitmap( Handle self, Handle image, PutImageRequest * req)
 	if ( !img_put_icon_mask( self, cache->icon, req))
 		return false;
 
-	req-> rop = ( rop == ropSrcCopy ) ? GXcopy : GXor;
+	req-> rop = ( rop == ropCopyPut ) ? GXcopy : GXor;
 	XSetForeground( DISP, XX-> gc, 1);
 	XSetBackground( DISP, XX-> gc, 0);
 	XX-> flags. brush_fore = XX-> flags. brush_back = 0;
@@ -1850,7 +1850,7 @@ img_put_image_on_pixmap( Handle self, Handle image, PutImageRequest * req)
 	if ( req-> transform ) \
 		XRenderSetPictureTransform( DISP, picture, &render_identity_transform)
 
-#define ROP_SRC_OR_COPY  (req-> rop == ropSrcCopy) ? PictOpSrc : PictOpOver
+#define ROP_SRC_OR_COPY  (req-> rop == ropCopyPut) ? PictOpSrc : PictOpOver
 #define RENDER_COMPOSITE( ofs, rop, picture )                    \
 	XRenderComposite(                                        \
 		DISP, rop,                                       \
@@ -2151,11 +2151,59 @@ FAIL:
 #endif
 }
 
+static Bool
+img_render_icon_on_picture( Handle self, Handle image, PutImageRequest * req, Bool on_layered)
+{
+#ifdef HAVE_X11_EXTENSIONS_XRENDER_H
+	DEFXX;
+	ImageCache *cache;
+	Pixmap pixmap;
+	GC gc;
+	XGCValues gcv;
+	Bool ret = false;
+	Picture picture;
+
+	/* XXX is 255 still good? request alpha_channel=255 because PictOpOver emulates SrcCopy here */
+	if (!(cache = prima_image_cache((PImage) image,
+		CACHE_LAYERED_ALPHA,
+		255, 255, 255)))
+		return false;
+
+	pixmap = XCreatePixmap( DISP, guts.root, req->w, req->h, guts.argb_visual.depth);
+	gcv. graphics_exposures = false;
+	gc = XCreateGC( DISP, pixmap, GCGraphicsExposures, &gcv);
+
+	SET_ROP(GXcopy);
+	if ( !( prima_put_ximage(
+		pixmap, gc, cache->image,
+		req->src_x, req->src_y, 0, 0,
+		req->w, req->h
+	))) goto FAIL;
+
+	picture = prima_render_create_picture(pixmap, 32);
+	RENDER_APPLY_TRANSFORM(picture);
+	printf("%d %d\n", req->rop,PIcon(image)->maskType);
+	RENDER_COMPOSITE( ofs,
+		(req-> rop == ropCopyPut && PIcon(image)->maskType == imbpp8) ? PictOpSrc : PictOpOver,
+		picture);
+	RENDER_FREE(picture);
+	XRENDER_SYNC_NEEDED;
+	ret = true;
+
+FAIL:
+	XFreeGC( DISP, gc);
+	XFreePixmap( DISP, pixmap );
+	return ret;
+#else
+	return false;
+#endif
+}
+
 static Bool
 img_render_image_on_pixmap( Handle self, Handle image, PutImageRequest * req)
 {
 	if ( XT_IS_ICON(X(image)))
-		return img_put_image_on_pixmap(self, image, req);
+		return img_render_icon_on_picture( self, image, req, false);
 	return img_render_image_on_picture( self, image, req, false);
 }
 
@@ -2163,7 +2211,7 @@ static Bool
 img_render_image_on_widget( Handle self, Handle image, PutImageRequest * req)
 {
 	if ( XT_IS_ICON(X(image)))
-		return img_put_image_on_widget(self, image, req);
+		return img_render_icon_on_picture( self, image, req, false);
 	return img_render_image_on_picture( self, image, req, false);
 }
 
@@ -2171,7 +2219,7 @@ static Bool
 img_render_image_on_layered( Handle self, Handle image, PutImageRequest * req)
 {
 	if ( XT_IS_ICON(X(image)))
-		return img_put_image_on_layered(self, image, req);
+		return img_render_icon_on_picture( self, image, req, true);
 	return img_render_image_on_picture( self, image, req, true);
 }
 
@@ -2387,7 +2435,7 @@ get_image_src_format( Handle self, Handle image, int * rop )
 }
 
 static PutImageFunc**
-get_image_dst_format( Handle self, int rop, int src_type, Bool use_xrender )
+get_image_dst_format( Handle self, Handle image, int rop, int src_type, Bool use_xrender )
 {
 	DEFXX;
 
@@ -2397,7 +2445,10 @@ get_image_dst_format( Handle self, int rop, int src_type, Bool use_xrender )
 		if ( !guts.render_supports_argb32 && src_type == SRC_ARGB )
 			return img_render_nullset;
 		/* xrender cannot rops */
-		if ( src_type != SRC_LAYERED && src_type != SRC_ARGB && rop != ropCopyPut )
+		if ( src_type != SRC_LAYERED && src_type != SRC_ARGB && rop != ropCopyPut && rop != ropBlend )
+			return img_render_nullset;
+		/* bpp1 requires xor/and rops */
+		if ( XT_IS_ICON(X(image)) && PIcon(image)->maskType == imbpp1)
 			return img_render_nullset;
 	}
 
@@ -2446,17 +2497,21 @@ apc_gp_put_image( Handle self, Handle image, int x, int y, int xFrom, int yFrom,
 #endif
 
 	src = get_image_src_format(self, image, &rop);
-	if ( rop > ropNoOper ) return false;
+	if ( src == SRC_LAYERED || src == SRC_ARGB ) {
+		if ( rop != ropCopyPut && rop != ropBlend ) return false;
+	} else {
+		if ( rop > ropWhiteness ) return false;
+	}
 	if ( src < 0 ) {
 		warn("cannot guess image type");
 		return false;
 	}
-	if (!(dst = get_image_dst_format(self, rop, src, true))) {
+	if (!(dst = get_image_dst_format(self, image, rop, src, true))) {
 		warn("cannot guess surface type");
 		return false;
 	}
 	if ( !dst[src] ) {
-		if (!( dst = get_image_dst_format(self, rop, src, false))) {
+		if (!( dst = get_image_dst_format(self, image, rop, src, false))) {
 			warn("cannot guess surface type");
 			return false;
 		}
@@ -2529,7 +2584,7 @@ apc_image_begin_paint( Handle self)
 		req.dst_w = req.w;
 		req.dst_h = req.h;
 #endif
-		req.rop = layered ? ropSrcCopy : GXcopy;
+		req.rop = layered ? ropCopyPut : GXcopy;
 		req.old_rop = XX-> gcv. function;
 		(*dst[layered ? SRC_ARGB : SRC_IMAGE])(self, self, &req);
 		/*                                     ^^^^^ ^^^^    :-)))  */
@@ -2977,13 +3032,16 @@ put_transformed(Handle self, Handle image, int x, int y, int rop, Matrix matrix)
 	memset(&fill, 0x0, sizeof(fill));
 
 	if ( XT_IS_ICON(YY)) {
+		int mt = PIcon(img)->maskType;
 		img->self->set_preserveType(image, 0);
 		img->self->matrix_transform(image, matrix, fill, &aperture);
 		x += aperture.x;
 		y += aperture.y;
 		if ( !guts.render_supports_argb32 )
 			CIcon(img)->set_maskType( self, imbpp1 );
-		return apc_gp_put_image( self, image, x, y, 0, 0, img->w, img-> h, ropXorPut);
+		if ( mt == 1 && PIcon(img)->maskType != 1 ) /* 1-bit icons can only xor, emulate with blend */
+			rop = ropBlend;
+		return apc_gp_put_image( self, image, x, y, 0, 0, img->w, img-> h, rop);
 	} else {
 		Handle ok;
 		Handle icon = img->self->convert_to_icon(image, imbpp8, NULL);
@@ -2992,6 +3050,8 @@ put_transformed(Handle self, Handle image, int x, int y, int rop, Matrix matrix)
 		y += aperture.y;
 		if ( !guts.render_supports_argb32 )
 			CIcon(icon)->set_maskType( icon, imbpp1 );
+		else
+			rop = ropBlend;
 		ok = apc_gp_put_image( self, icon, x, y, 0, 0, PIcon(icon)->w, PIcon(icon)->h, rop);
 		Object_destroy(icon);
 		return ok;
@@ -3015,7 +3075,11 @@ apc_gp_stretch_image_x11( Handle self, Handle image,
 	if ( !XF_IN_PAINT(XX)) return false;
 
 	src = get_image_src_format(self, image, &rop);
-	if ( rop > ropNoOper ) return false;
+	if ( src == SRC_LAYERED || src == SRC_ARGB ) {
+		if ( rop != ropCopyPut && rop != ropBlend ) return false;
+	} else {
+		if ( rop > ropWhiteness ) return false;
+	}
 	if ( src < 0 ) return false;
 
 	XRENDER_SYNC;
@@ -3220,10 +3284,14 @@ apc_gp_stretch_image( Handle self, Handle image,
 		goto FALLBACK;
 
 	src = get_image_src_format(self, image, &rop);
-	if ( rop > ropNoOper ) return false;
+	if ( src == SRC_LAYERED || src == SRC_ARGB ) {
+		if ( rop != ropCopyPut && rop != ropBlend ) return false;
+	} else {
+		if ( rop > ropWhiteness ) return false;
+	}
 	if ( src < 0 ) return false;
 
-	if (!(dst = get_image_dst_format(self, rop, src, true))) {
+	if (!(dst = get_image_dst_format(self, image, rop, src, true))) {
 		warn("cannot guess surface type");
 		return false;
 	}
@@ -3234,8 +3302,6 @@ apc_gp_stretch_image( Handle self, Handle image,
 		case ropNoOper:
 			return true;
 		case ropCopyPut:
-			break;
-		case ropSrcCopy:
 			if ( X(image)->flags.layered)
 				break;
 		default:
