@@ -230,6 +230,7 @@ load_pointer_font( void)
 static void
 draw_poly( Handle self, int n_points, Point * pts, int dx, int dy)
 {
+	int j;
 	PIcon i = (PIcon) self;
 	ImgPaintContext ctx = {
 		{0,0,0,0},
@@ -239,10 +240,14 @@ draw_poly( Handle self, int n_points, Point * pts, int dx, int dy)
 		{0,0},
 		NULL_HANDLE,
 		lpSolid,
-		NULL,
-		{dx,dy}
+		NULL
 	};
 	Image mask;
+
+	for ( j = 0; j < n_points; j++) {
+		pts[j].x += dx;
+		pts[j].y += dy;
+	}
 	img_fill_dummy(&mask, i->w, i->h, i->maskType, i->mask, NULL);
 	ctx.region = img_region_polygon( pts, n_points, fmWinding);
 	memset( &ctx.color, 0xff, sizeof(ctx.color));
@@ -255,6 +260,10 @@ draw_poly( Handle self, int n_points, Point * pts, int dx, int dy)
 	memset( &ctx.color, 0x0, sizeof(ctx.color));
 	img_polyline( self, n_points, pts, &ctx);
 	img_polyline((Handle) &mask, n_points, pts, &ctx);
+	for ( j = 0; j < n_points; j++) {
+		pts[j].x -= dx;
+		pts[j].y -= dy;
+	}
 }
 
 static void
@@ -403,17 +412,11 @@ xlib_cursor_load( Handle self, int id, Handle icon)
 	CIcon(icon)-> create_empty( icon, w, h, imBW);
 	if (( im = XGetImage( DISP, p1, 0, 0, w, h, 1, XYPixmap)) == NULL)
 		goto FAIL;
-	prima_copy_xybitmap(
-		PIcon(icon)-> data, (Byte*)im-> data,
-		PIcon(icon)-> w, PIcon(icon)-> h,
-		PIcon(icon)-> lineSize, im-> bytes_per_line);
+	prima_copy_1bit_ximage(PIcon(icon)-> data, im, false);
 	XDestroyImage( im);
 	if (( im = XGetImage( DISP, p2, 0, 0, w, h, 1, XYPixmap)) == NULL)
 		goto FAIL;
-	prima_copy_xybitmap(
-		PIcon(icon)-> mask, (Byte*)im-> data,
-		PIcon(icon)-> w, PIcon(icon)-> h,
-		PIcon(icon)-> maskLine, im-> bytes_per_line);
+	prima_copy_1bit_ximage( PIcon(icon)-> mask, im, false);
 	if ( cp != NULL ) {
 		int i;
 		Byte * mask = PIcon(icon)-> mask;
