@@ -130,31 +130,21 @@ font_context_next( FontContext * fc )
 	return len;
 }
 
-/* emulate underscore and strikeout because ExtTextOutW with ETO_PDY underlines each glyph separately */
+/*
+	emulate underscore and strikeout because ExtTextOutW with ETO_PDY underlines each glyph separately .
+	Also, Gdip ignores viewport, specify params in parallel
+*/
 static void
-underscore_font( Handle self, int x, int y, int width, Bool use_alpha)
+underscore_font( Handle self, int x1, int y1, int x2, int y2, int width, Bool use_alpha)
 {
 	HDC dc = sys ps;
-	float c, s;
 	GpPen * gppen = NULL;
-
-	if ( var font. direction != 0) {
-		if ( sys font_sin == sys font_cos && sys font_sin == 0.0 ) {
-			sys font_sin = sin( var font. direction / GRAD);
-			sys font_cos = cos( var font. direction / GRAD);
-		}
-		c = sys font_cos;
-		s = sys font_sin;
-	} else {
-		s = 0.0;
-		c = 1.0;
-	}
+	NPoint cs = CDrawable(self)->trig_cache(self);
 
 	if ( var font. style & (fsUnderlined|fsStruckOut)) {
 		int line_width = 1;
 		COLORREF fg = sys rq_pen.logpen.lopnColor;
-		if (sys otmsUnderscoreSize > 0)
-			line_width = sys otmsUnderscoreSize;
+		line_width = var font. underlineThickness;
 		if ( use_alpha ) {
 			gppen = stylus_gp_get_pen(line_width,
 				( sys alpha << 24) |
@@ -174,10 +164,7 @@ underscore_font( Handle self, int x, int y, int width, Bool use_alpha)
 
 		if ( !is_apt( aptTextOutBaseline))
 			Y -= var font. descent;
-		if (sys otmsUnderscoreSize > 0)
-			Y -= sys otmsUnderscorePosition;
-		else
-			Y += var font. descent - 1;
+		Y -= var font. underlinePosition;
 
 		pt[0].x = 0;
 		pt[0].y = -Y;
@@ -185,18 +172,18 @@ underscore_font( Handle self, int x, int y, int width, Bool use_alpha)
 		pt[1].y = -Y;
 		if ( var font. direction != 0) {
 			for ( i = 0; i < 2; i++) {
-				float x = pt[i].x * c - pt[i].y * s;
-				float y = pt[i].x * s + pt[i].y * c;
+				float x = pt[i].x * cs.y - pt[i].y * cs.x;
+				float y = pt[i].x * cs.x + pt[i].y * cs.y;
 				pt[i].x = x + (( x > 0) ? 0.5 : -0.5);
 				pt[i].y = y + (( y > 0) ? 0.5 : -0.5);
 			}
 		}
 
 		if ( use_alpha ) {
-			GdipDrawLineI(sys graphics, gppen, x + pt[0].x, y - pt[0].y, x + pt[1].x, y - pt[1].y);
+			GdipDrawLineI(sys graphics, gppen, x2 + pt[0].x, y2 - pt[0].y, x2 + pt[1].x, y2 - pt[1].y);
 		} else {
-			MoveToEx( dc, x + pt[0].x, y - pt[0].y, NULL);
-			LineTo( dc, x + pt[1].x, y - pt[1].y);
+			MoveToEx( dc, x1 + pt[0].x, y1 - pt[0].y, NULL);
+			LineTo( dc, x1 + pt[1].x, y1 - pt[1].y);
 		}
 	}
 
@@ -209,7 +196,7 @@ underscore_font( Handle self, int x, int y, int width, Bool use_alpha)
 		if (sys otmsStrikeoutSize > 0)
 			Y -= sys otmsStrikeoutPosition;
 		else
-			Y -= var font. ascent / 2;
+			Y -= (var font. ascent - var font. internalLeading) / 3;
 
 		pt[0].x = 0;
 		pt[0].y = -Y;
@@ -217,18 +204,18 @@ underscore_font( Handle self, int x, int y, int width, Bool use_alpha)
 		pt[1].y = -Y;
 		if ( var font. direction != 0) {
 			for ( i = 0; i < 2; i++) {
-				float x = pt[i].x * c - pt[i].y * s;
-				float y = pt[i].x * s + pt[i].y * c;
+				float x = pt[i].x * cs.y - pt[i].y * cs.x;
+				float y = pt[i].x * cs.x + pt[i].y * cs.y;
 				pt[i].x = x + (( x > 0) ? 0.5 : -0.5);
 				pt[i].y = y + (( y > 0) ? 0.5 : -0.5);
 			}
 		}
 
 		if ( use_alpha ) {
-			GdipDrawLineI(sys graphics, gppen, x + pt[0].x, y - pt[0].y, x + pt[1].x, y - pt[1].y);
+			GdipDrawLineI(sys graphics, gppen, x2 + pt[0].x, y2 - pt[0].y, x2 + pt[1].x, y2 - pt[1].y);
 		} else {
-			MoveToEx( dc, x + pt[0].x, y - pt[0].y, NULL);
-			LineTo( dc, x + pt[1].x, y - pt[1].y);
+			MoveToEx( dc, x1 + pt[0].x, y1 - pt[0].y, NULL);
+			LineTo( dc, x1 + pt[1].x, y1 - pt[1].y);
 		}
 	}
 }
@@ -467,7 +454,7 @@ apc_gp_text_out( Handle self, const char * text, int x, int y, int len, int flag
 	}
 
 	if ( var font. style & (fsUnderlined | fsStruckOut))
-		underscore_font( self, 0, 0, gp_get_text_width( self, text, len, flags), use_alpha);
+		underscore_font( self, 0, 0, x, y, gp_get_text_width( self, text, len, flags), use_alpha);
 
 	if ( use_path ) {
 		EndPath(ps);
@@ -585,7 +572,8 @@ apc_gp_glyphs_out( Handle self, PGlyphsOutRec t, int x, int y)
 	int opa = is_apt( aptTextOpaque) ? OPAQUE : TRANSPARENT;
 	Bool use_path, use_alpha;
 	FontContext fc;
-	float s, c, fxx, fyy;
+	float fxx, fyy;
+	NPoint cs = CDrawable(self)->trig_cache(self);
 
 	select_world_transform(self, true);
 	SHIFT_XY(x,y);
@@ -605,18 +593,6 @@ apc_gp_glyphs_out( Handle self, PGlyphsOutRec t, int x, int y)
 		if ( opa != bk) SetBkMode( ps, opa);
 	}
 
-	if ( var font. direction != 0) {
-		if ( sys font_sin == sys font_cos && sys font_sin == 0.0 ) {
-			sys font_sin = sin( var font. direction / GRAD);
-			sys font_cos = cos( var font. direction / GRAD);
-		}
-		s = sys font_sin;
-		c = sys font_cos;
-	} else {
-		c = 1.0;
-		s = 0.0;
-	}
-
 	fxx = xx = 0;
 	fyy = yy = 0;
 	savelen = t->len;
@@ -629,8 +605,8 @@ apc_gp_glyphs_out( Handle self, PGlyphsOutRec t, int x, int y)
 			))
 			break;
 		if ( !fc.stop ) {
-			fxx += (float)advance * c;
-			fyy -= (float)advance * s;
+			fxx += (float)advance * cs.y;
+			fyy -= (float)advance * cs.x;
 			xx = fxx + ((fxx < 0) ? -.5 : +.5);
 			yy = fyy + ((fyy < 0) ? -.5 : +.5);
 
@@ -645,7 +621,7 @@ apc_gp_glyphs_out( Handle self, PGlyphsOutRec t, int x, int y)
 	t->len = savelen;
 
 	if ( var font. style & (fsUnderlined | fsStruckOut))
-		underscore_font( self, 0, yy, gp_get_glyphs_width( self, t, 0), use_alpha);
+		underscore_font( self, 0, yy, x, y + yy, gp_get_glyphs_width( self, t, 0), use_alpha);
 
 	if ( use_path ) {
 		EndPath(ps);
@@ -1117,7 +1093,7 @@ win32_unicode_mapper( Handle self, PTextShapeRec t)
 }
 
 PTextShapeFunc
-apc_gp_get_text_shaper( Handle self, int * type)
+apc_font_get_text_shaper( Handle self, int * type)
 {
 	if ( *type == tsBytes ) {
 		*type = (sys tmPitchAndFamily & (TMPF_TRUETYPE|TMPF_OPENTYPE)) ?
@@ -1507,7 +1483,7 @@ apc_gp_get_mapper_ranges(PFont font, int * count, unsigned int * flags)
 	*count = 0;
 
 	strlcpy(name, font->name, 256);
-	apc_font_pick( NULL_HANDLE, font, font);
+	apc_font_pick( NULL_HANDLE, font, NULL);
 	if ( strcmp( font->name, name ) != 0 ) 
 		return NULL;
 
@@ -1846,41 +1822,8 @@ apc_gp_get_glyphs_width( Handle self, PGlyphsOutRec t)
 void
 gp_get_text_box( Handle self, ABC * abc, Point * pt)
 {
-	pt[0].y = pt[2]. y = var font. ascent - 1;
-	pt[1].y = pt[3]. y = - var font. descent;
-	pt[4].y = pt[0]. x = pt[1].x = 0;
-	pt[3].x = pt[2]. x = pt[4].x = abc->abcB;
-
-	if ( !is_apt( aptTextOutBaseline)) {
-		int i = 4, d = var font. descent;
-		while ( i--) pt[ i]. y += d;
-	}
-
-	if ( abc->abcA < 0) {
-		pt[0].x += abc->abcA;
-		pt[1].x += abc->abcA;
-	}
-	if ( abc->abcC < 0) {
-		pt[2].x -= abc->abcC;
-		pt[3].x -= abc->abcC;
-	}
-
-	if ( var font. direction != 0) {
-		int i;
-		float s, c;
-		if ( sys font_sin == sys font_cos && sys font_sin == 0.0 ) {
-			sys font_sin = sin( var font. direction / GRAD);
-			sys font_cos = cos( var font. direction / GRAD);
-		}
-		s = sys font_sin;
-		c = sys font_cos;
-		for ( i = 0; i < 5; i++) {
-			float x = pt[i]. x * c - pt[i]. y * s;
-			float y = pt[i]. x * s + pt[i]. y * c;
-			pt[i]. x = x + (( x > 0) ? 0.5 : -0.5);
-			pt[i]. y = y + (( y > 0) ? 0.5 : -0.5);
-		}
-	}
+	Point ovx = { abc->abcA, abc->abcC };
+	Drawable_calculate_text_box( self, abc->abcB, is_apt(aptTextOutBaseline), ovx, pt);
 }
 
 Point *
@@ -1925,7 +1868,7 @@ apc_gp_get_glyphs_box( Handle self, PGlyphsOutRec t)
 }}
 
 int
-apc_gp_get_glyph_outline( Handle self, int index, int flags, int ** buffer)
+apc_gp_get_glyph_outline( Handle self, unsigned int index, unsigned int flags, int ** buffer)
 {
 	int offset, gdi_size, r_size, *r_buf, *r_ptr;
 	Byte * gdi_buf;
@@ -2080,6 +2023,87 @@ apc_gp_set_text_out_baseline( Handle self, Bool baseline)
 	return true;
 }
 
+Bool
+apc_font_begin_query( Handle self )
+{
+	if ( !( sys ps = CreateCompatibleDC( NULL )))
+		return false;
+	return true;
+}
+
+void
+apc_font_end_query( Handle self )
+{
+	DeleteDC( sys ps );
+	sys ps = 0;
+}
+
+Byte*
+apc_font_get_glyph_bitmap( Handle self, uint16_t index, unsigned int flags, PPoint offset, PPoint size, int *advance)
+{
+	int gdi_size;
+	Byte * gdi_buf;
+	GLYPHMETRICS gm;
+	MAT2 matrix;
+	UINT format;
+	Matrix *m = &var current_state.matrix;
+
+	memset(&matrix, 0, sizeof(matrix));
+#define FLOAT2FIXED(field,val) \
+	matrix.field.value = ((val) < 0) ? ((short)(val)) - 1 : ((short)(val));\
+	matrix.field.fract = ((val) - matrix.field.value) * 65535
+	FLOAT2FIXED(eM11, (*m)[0]);
+	FLOAT2FIXED(eM12, -(*m)[1]);
+	FLOAT2FIXED(eM21, (*m)[2]);
+	FLOAT2FIXED(eM22, -(*m)[3]);
+#undef FLOAT2FIXED
+	select_world_transform(self, false);
+
+	format = GGO_GLYPH_INDEX |
+		(( flags & ggoMonochrome ) ? GGO_BITMAP : GGO_GRAY8_BITMAP) |
+		(( flags & ggoUseHints )   ? 0          : GGO_UNHINTED)
+		;
+	if (( gdi_size = GetGlyphOutlineW(sys ps, index, format, &gm, 0, NULL, &matrix)) < 0 )
+		return NULL;
+	if (( gdi_buf = malloc(gdi_size)) == NULL ) {
+		warn("Not enough memory");
+		return NULL;
+	}
+
+	if ( GetGlyphOutlineW(sys ps, index, format, &gm, gdi_size, gdi_buf, &matrix) == GDI_ERROR) {
+		apiErr;
+		free(gdi_buf);
+		return NULL;
+	}
+
+	size-> x   = gm.gmBlackBoxX;
+	size-> y   = gm.gmBlackBoxY;
+	offset-> x = gm.gmptGlyphOrigin.x;
+	offset-> y =-gm.gmptGlyphOrigin.y;
+	if ( gdi_size == 0 )
+		size-> x = size-> y = 0;
+	if ( advance ) {
+		ABC x;
+		if (GetCharABCWidthsI( sys ps, index, 1, NULL, &x)) {
+			*advance = x.abcA + x.abcB + x.abcC;
+		} else {
+			*advance = gm.gmCellIncX;
+			apiErr;
+		}
+	}
+
+	if ( !( flags & ggoMonochrome)) {
+		register Byte* buf = gdi_buf;
+		register unsigned int bytes = size->y * (( size->x * 8 + 31) / 32) * 4;
+		while (bytes--) {
+			*buf = *buf * 3.984 + .5; /* 255/64 */
+			buf++;
+		}
+	}
+
+	return gdi_buf;
+}
+
 #ifdef __cplusplus
 }
 #endif
